@@ -17,7 +17,7 @@ def crop(input_file, page_option: list):
         if len(option) > 2:
             space = option[2]
         if len(option) > 3:
-            space = option[3]
+            threshold = option[3]
         pdf_crop = PymuPDFCrop(input_file=input_file, space=space, threshold=threshold)
         output_file, media_box, crop_box = pdf_crop.crop(page_no, output_file=output_file, crop_box=None)
         table.add_row(str(option[0]), rect_str(media_box), rect_str(crop_box), output_file)
